@@ -22,7 +22,7 @@ use JSON;
 use Try::Tiny;
 use HiPi::RF::OpenThings::Message;
 
-our $VERSION ='0.62';
+our $VERSION ='0.63';
 
 __PACKAGE__->create_accessors( qw( config result mode display options pretty user console_display_message) );
 
@@ -549,6 +549,12 @@ sub command_group {
                    
         for my $group( keys %{ $self->conf->{groups} } ) {
             if(lc($self->conf->{groups}->{$group}) eq lc($delete) ) {
+                # delete any grouped switches first
+                for my $switchname ( keys %{ $self->conf->{switches} } ) {
+                    if( $self->conf->{switches}->{$switchname}->{group} == $group ) {
+                        delete($self->conf->{switches}->{$switchname});
+                    }
+                }
                 delete($self->conf->{groups}->{$group});
                 $self->list_groups('delete');
                 return;
@@ -911,14 +917,7 @@ sub command_alias {
         if(   $self->conf->{switches}->{$switchname}->{switch} == $switch
            && $self->conf->{switches}->{$switchname}->{group} == $group )
         {
-            # to hang on to a temp ref here cos we can alias to the
-            # same name again
-            my $tempconf = $self->conf->{switches}->{$switchname};
             delete($self->conf->{switches}->{$switchname});
-            $self->conf->{switches}->{$name} = $tempconf;
-           
-            $self->list_switches('alias');
-            return;
         }
     }
     
